@@ -12,10 +12,10 @@ from tqdm import tqdm
 from rebotics_sdk.cli.common import shell, configure, roles, set_token
 from .utils import ReboticsCLIContext, pass_rebotics_context, app_dir, read_saved_role, process_role
 from ..advanced import remote_loaders
+from ..constants import DownloadImagesFormat
 from ..providers import DatasetProvider, ProviderHTTPClientException
 from ..providers.utils import get_id_list_from_ranges
 from ..utils import download_file, mkdir_p, get_filename_from_url
-from ..constants import DownloadImagesFormat
 
 
 @click.group()
@@ -134,8 +134,8 @@ def upload_ref(ctx, ref_upc, ref_features, ref_threshold, retailer, facenet, bat
 
     result = []
     for res in tqdm(
-            pool.imap_unordered(task_upload_feature_vector_batch, [(ctx, d, i) for i, d in enumerate(batches)]),
-            total=len(batches)
+        pool.imap_unordered(task_upload_feature_vector_batch, [(ctx, d, i) for i, d in enumerate(batches)]),
+        total=len(batches)
     ):
         result.append(res)
 
@@ -174,7 +174,7 @@ def download_ref_backup(ctx, retailer, facenet, output):
 def task_download_and_set_training_data(item_id, target, format, ctx):
     try:
         response = ctx.provider.get_detection_image_by_id(item_id)
-    except:
+    except Exception:
         click.echo("Failed to find image with id={}".format(item_id))
         return
     # download images and download this json
@@ -186,7 +186,7 @@ def task_download_and_set_training_data(item_id, target, format, ctx):
         )
         try:
             remote_loaders.download(image_url, str(image_file))
-        except:
+        except Exception:
             click.echo("{} failed to download image from {}".format(item_id, image_url))
     if format in (DownloadImagesFormat.FULL, DownloadImagesFormat.ANNOTATIONS):
         json_file = target / "{}.json".format(item_id)
@@ -200,7 +200,7 @@ def task_download_and_set_training_data(item_id, target, format, ctx):
 @click.option('-c', '--concurrency', type=int, default=4)
 @click.option('-f', '--format',
               type=click.Choice(DownloadImagesFormat.OPTIONS, case_sensitive=False),
-              default=DownloadImagesFormat.FULL,)
+              default=DownloadImagesFormat.FULL, )
 @pass_rebotics_context
 def download_images(ctx, image_ids, target, concurrency, format):
     """Download images and/or annotations json."""
@@ -219,7 +219,7 @@ def download_images(ctx, image_ids, target, concurrency, format):
             partial(task_download_and_set_training_data,
                     target=pathlib.Path(target),
                     format=format,
-                    ctx=ctx,),
+                    ctx=ctx, ),
             id_list
         )
     pool.join()
